aboutsummaryrefslogtreecommitdiffstats
path: root/include/ui/widgets/TextEdit.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/ui/widgets/TextEdit.h')
-rw-r--r--include/ui/widgets/TextEdit.h10
1 files changed, 8 insertions, 2 deletions
diff --git a/include/ui/widgets/TextEdit.h b/include/ui/widgets/TextEdit.h
index f98da145..99b8bcc7 100644
--- a/include/ui/widgets/TextEdit.h
+++ b/include/ui/widgets/TextEdit.h
@@ -82,10 +82,16 @@ public:
public slots:
/**
* @details Return pointer to the currently activated tabpage.
*
*/
- [[nodiscard]] EditorPage *slotCurPage() const;
+ [[nodiscard]] EditorPage *slotCurPageTextEdit() const;
+
+ /**
+ * @details Return pointer to the currently activated file treeview tab page.
+ *
+ */
+ [[nodiscard]] FilePage *slotCurPageFileTreeView() const;
/**
* @details Insert a ">" at the begining of every line of current textedit.
@@ -82,10 +82,16 @@ public:
public slots:
/**
- * @details Return pointer to the currently activated tabpage.
+ * @details Return pointer to the currently activated text edit tab page.
*
*/